# plugin.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

from TorrentSearch.SearchPlugin import SearchPlugin
import urllib, time, datetime

class ThePirateBaySearchPlugin(SearchPlugin):
    def _process_search(self, pattern, page_url = ""):
        if page_url == "":
            page_url = "http://thepiratebay.se/search/" + urllib.quote_plus(pattern)
        
        resp, content = self._http_request(page_url)
        tree = self._parse_html(content)
        
        try:
            self.results_count = int(tree.lookup_children("h2")[0].lookup_children("span")[0].tail.split("(")[1].split(" ")[1])
        except:
            pass
        
        results_table = tree.lookup_children("table", id = "searchResult")[0]
        results_lines = results_table.lookup_children("tr", 0)

        for result in results_lines:
            try:
                self._parse_result(page_url, result)
            except:
                pass
            if self.must_stop():
                return
        
        if self.must_stop():
            return

        try:
            next_page_link = tree.lookup_children("div", id = "main-content")[0].next.lookup_children("img", alt = "Next")[0].getparent()
            page = next_page_link.href.split("/")[3]
            next_page_url = "http://thepiratebay.se/search/" + urllib.quote_plus(pattern) + "/" + page
            if next_page_url != page_url:
                self._process_search(pattern, next_page_url)
        except:
            pass
    
    def _parse_date(self, data):
        try: # Date this year ?
            res = time.strptime(data, "%m-%d %H:%M")
            res = datetime.date(datetime.date.today().year, res.tm_mon, res.tm_mday)
        except:
            try: # Date before this year ?
                res = time.strptime(data, "%m-%d %Y")
                res = datetime.date(res.tm_year, res.tm_mon, res.tm_mday)
            except:
                if data.split(" ")[0] == "Y-day": # Yesterday ?
                   res = datetime.date.today() - datetime.timedelta(1)
                else: # Today
                   res = datetime.date.today()
        return res
    
    def _parseCat(self, main_cat, sub_cat):
        if main_cat=="Audio":
            if sub_cat=="Music":
                return "audio/music"
            else:
                return "audio"
                
        if main_cat=="Video":
            if sub_cat  in ["Movies","Movies DVDR","Highres - Movies"]:
                return "video/movie"
            elif sub_cat in ["TV shows","Highres - TV shows"]:
                return "video/tv"
            elif sub_cat=="Music videos":
                return "video/music"
            return "video"
            
        if main_cat=="Applications":
            return "software"
            
        if main_cat=="Games":
            if sub_cat=="PC":
                return "software/game/pc"
            elif sub_cat=="PS2":
                return "software/game/ps2"
            elif sub_cat=="XBOX360":
                return "software/game/xbox360"
            elif sub_cat=="Mac":
                return "software/game/mac"
            elif sub_cat=="Wii":
                return "software/game/wii"
                
        if main_cat=="Porn":
            if sub_cat  in ["Movies","Movies DVDR","Highres - Movies"]:
                return "video/xxx"
            return ""
            
        return ""
    
    def _parse_result(self, page_url, result_line):
        cat_cell, main_cell, seeders_cell, leechers_cell = result_line.lookup_children("td", 0)

        main_cat, sub_cat = cat_cell.lookup_children("a")
        main_cat = main_cat.getContent()
        sub_cat = sub_cat.getContent()
        cat = self._parseCat(main_cat, sub_cat)

        seeders = int(seeders_cell.getContent())
        leechers = int(leechers_cell.getContent())

        title_link = main_cell.lookup_children("a", **{"class": "detLink"})[0]
        title = title_link.getContent()
        details_page_url = urllib.basejoin(page_url, title_link.href)

        magnet_link = main_cell.lookup_children("a", 1)[1]
        magnet_url = magnet_link.href

        nb_comments = 0
        comments_img = main_cell.lookup_children("img", src = "//static.thepiratebay.se/img/icon_comment.gif")
        if comments_img:
            try:
                data = comments_img[0].title
                nb_comments = int(data[17:-10])
            except:
                pass

        date_size_data = main_cell.lookup_children("font")[0].getContent()
        date_size_data = date_size_data.replace(chr(194)+chr(160), ' ')

        date_data, size_data = date_size_data.split(',')[:2]

        date_data = date_data[9:]
        date = self._parse_date(date_data)

        size_data = size_data[6:]
        size = size_data.replace("i", "").replace(chr(160), " ")
        size, size_unit = size.split(" ")
        size = self._convert_size(float(size), size_unit)
        
        self._add_result(
            page_url = details_page_url,
            additional_infos_url = details_page_url,
            title = title,
            size = size,
            date = date,
            seeders = seeders,
            leechers = leechers,
            nb_comments = nb_comments,
            magnet_link = magnet_url,
            category = cat
        )
