# HTMLTools.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

import lxml.html

class HTMLNode(object):
    def __init__(self, node):
        self._node = node
    
    def lookup_children(self, elname = None, maxdepth = -1, **params):
        res = []
        
        for node in self._node:
            if elname == None or node.tag == elname:
                add = True
                for i in params:
                    if node.get(i) != params[i]:
                        add = False
                        break
                if add:
                    res.append(HTMLNode(node))
            if maxdepth != 0:
                res += HTMLNode(node).lookup_children(elname, maxdepth - 1, **params)
                    
        return res
    
    def __repr__(self):
        return repr(self._node)
        
    def __str__(self):
        return str(self._node)
    
    def _get_next(self):
        node = self._node.getnext()
        if node == None:
            return None
        else:
            return HTMLNode(node)
    next = property(_get_next)
    
    def getContent(self):
        if type(self._node.text) == str:
            res = self._node.text
        elif type(self._node.text) == unicode:
            res = self._node.text.encode('utf-8')
        else:
            res = ""
        for node in self._node:
            res += HTMLNode(node).getContent()
            if node.tail:
                res += node.tail
        return res
    
    def getparent(self):
        return HTMLNode(self._node.getparent())
    
    def __getattribute__(self, key):
        try:
            return object.__getattribute__(self, key)
        except:
            try:
                return getattr(self._node, key)
            except:
                return self._node.get(key)

class HTMLDocument(HTMLNode):
    def __init__(self, html_content):
        HTMLNode.__init__(self, lxml.html.document_fromstring(html_content))
