# PluginsUpdater.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

import threading, time
from .EventsObject import EventsObject

class PluginsUpdater(EventsObject):
    def __init__(self, application):
        EventsObject.__init__(self)
        self._application = application
        self._finished = False
        self._finished_lock = threading.Lock()
        self._progress = 0
        self._progress_lock = threading.Lock()
    
    def _get_progress(self):
        self._progress_lock.acquire()
        res = self._progress
        self._progress_lock.release()
        return res
    def _set_progress(self, value):
        self._progress_lock.acquire()
        self._progress = value
        self._progress_lock.release()
    progress = property(_get_progress, _set_progress)
    
    def _get_finished(self):
        self._finished_lock.acquire()
        res = self._finished
        self._finished_lock.release()
        return res
    def _set_finished(self, value):
        self._finished_lock.acquire()
        self._finished = value
        self._finished_lock.release()
    finished = property(_get_finished, _set_finished)
    
    def _do_run(self):
        """
        time.sleep(2)
        for i in range(50):
            time.sleep(0.1)
            self.progress = (i+1) / 50.
        """
        self.finished = True
    
    def run(self):
        self.progress = 0
        threading.Thread(None, self._do_run).start()
        self._application.timeout_add(100, self._check_progress)
    
    def _check_progress(self):
        if self.finished:
            self._trigger_event("finished")
            return False
        else:
            if self.progress > 0:
                self._trigger_event("progress")
            else:
                self._trigger_event("pulse")
            return True
