# env.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

import os, platform, sys
from .informations import *

if platform.system() == "Linux":
    APPDATA_PATH = os.path.join(os.getenv('HOME'), "." + UNIX_APPNAME)
    DEFAULT_SHARE_PATH = "/usr/share"
    PLATFORM = "linux"
    FRONTENDS_PRIORITY = ["gtk3", "gtk2", "curses"]
else:
    APPDATA_PATH = os.path.join(os.getenv('APPDATA'), UNIX_APPNAME)
    DEFAULT_SHARE_PATH = os.path.join(os.path.split(sys.argv[0])[0], "share")
    PLATFORM = "windows"
    FRONTENDS_PRIORITY = ["gtk2"]

def mime_get_all_applications(mimetype):
    paths = os.getenv("XDG_DATA_DIRS", "/usr/local/share:/usr/share").split(":")
    paths += os.getenv("XDG_DATA_HOME", "~/.local/share").split(":")
    
    list_files=[]
    for i in paths:
        path = os.path.join(os.path.realpath(i.replace("~", os.getenv('HOME'))), "applications")
        mimeinfo = os.path.join(path, "mimeinfo.cache")
        if os.path.exists(mimeinfo) and os.access(mimeinfo, os.R_OK):
            list_files.append(mimeinfo)
    
    desktops = {}
    for i in list_files:
        f = open(i)
        lines = f.read().splitlines()
        f.close()
        for j in lines:
            try:
                mtype, ds = j.split("=")
                if mtype == mimetype:
                    for k in ds.split(";"):
                        if k and not k in desktops:
                            if not k in desktops:
                                filename = os.path.join(os.path.split(i)[0], k)
                                if os.path.exists(filename):
                                    desktops[k] = filename
                                elif "-" in k:
                                    l = k.index("-")
                                    filename = os.path.join(os.path.split(i)[0], k[:l], k[l+1:])
                                    if os.path.exists(filename):
                                        desktops[k] = filename
            except:
                pass
    
    res = []
    for i in desktops:
        try:
            command = None
            title = None
            f = open(desktops[i])
            lines = f.read().splitlines()
            f.close()
            for j in lines:
                try:
                    k = j.index("=")
                    key = j[:k]
                    value = j[k+1:]
                    if key == "Exec" and command == None:
                        command = value
                    if key == "Name" and title == None:
                        title = value
                except:
                    pass
            if command and title:
                res.append((i, title, command))
        except:
            pass
            
    return res

def list_torrent_clients_linux():
    res = []
    for client_id, label, command in mime_get_all_applications("application/x-bittorrent"):
        res.append({
            "client_id": client_id,
            "label": label,
            "command": command
        })
    return res

def list_torrent_clients_windows():
    return []

def list_torrent_clients():
    if PLATFORM == "windows":
        return list_torrent_clients_windows()
    else:
        return list_torrent_clients_linux()
