# __init__.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

from ..env import FRONTENDS_PRIORITY
import logging, sys

def load_frontend(frontend_choice, application, share_dir):
    if frontend_choice != "_":
        if frontend_choice in FRONTENDS_PRIORITY:
            i = FRONTENDS_PRIORITY.index(frontend_choice)
            del FRONTENDS_PRIORITY[i]
            FRONTENDS_PRIORITY.insert(0, frontend_choice)
        else:
            logging.error("Frontend \"%s\" is not available" % frontend_choice)
    
    for frontend_name in FRONTENDS_PRIORITY:
        try:
            if frontend_name == "gtk3":
                from .gtk3.frontend import Gtk3Frontend
                return Gtk3Frontend(application, share_dir)
            elif frontend_name == "gtk2":
                from .gtk2.frontend import Gtk2Frontend
                return Gtk2Frontend(application, share_dir)
            elif frontend_name == "curses":
                from .curses.frontend import CursesFrontend
                return CursesFrontend(application, share_dir)
            elif frontend_name == "win32":
                from .win32.frontend import Win32Frontend
                return Win32Frontend(application, share_dir)
        except:
            logging.error("Failed loading \"%s\" frontend : %s" % (frontend_name, str(sys.exc_info()[1])))
            pass
    
    return None
