# frontend.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

from TorrentSearch.informations import *
import os, logging, curses
from TorrentSearch.EventsObject import EventsObject

MAIN_MENU = [
    {'label': _("Search"), "action": "run_search"},
    {'label': _("Preferences"), "action": "show_preferences"},
    {'label': _("Exit"), "action": "exit"},
]

class CursesFrontend(EventsObject):
    def __init__(self, application, share_path):
        EventsObject.__init__(self)
        
        self._application = application
        self._share_path = share_path
        
        self._should_quit = False
    
    def init(self):
        self._window = curses.initscr()
    
    def timeout_add(self, delay, callback, *args):
        pass
    
    def _show_menu(self):
        self._window.clear()
        self._window.border(0)
        self._window.addstr(0, 1, " " + APPNAME + " / " + _("Menu") + " ")
        
        actions = {}
        
        line = 2
        item_nb = 1
        for menu_item in MAIN_MENU:
            self._window.addstr(line, 4, str(item_nb) + " - " + menu_item["label"])
            actions[ord(str(item_nb))] = menu_item["action"]
            line += 1
            item_nb += 1
        self._window.refresh()
        
        resp = ""
        while not resp in actions:
            resp = self._window.getch()
        
        if actions[resp] == "exit":
            self._should_quit = True
        elif actions[resp] == "show_preferences":
            self._show_preferences()
    
    def _show_preferences(self):
        self._window.clear()
        self._window.border(0)
        self._window.addstr(0, 1, " " + APPNAME + " / " + _("Preferences") + " ")
        self._window.getch()
        
    def mainloop(self):
        while not self._should_quit:
            self._show_menu()
            
        curses.endwin()
