# ResultsList.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

import gtk
from TorrentSearch.EventsObject import EventsObject

class ResultsList(gtk.TreeView, EventsObject):
    def __init__(self, application):
        gtk.TreeView.__init__(self)
        EventsObject.__init__(self)
        
        self._model = gtk.ListStore(object)
        self._filtered_model = self._model.filter_new()
        self._filtered_model.set_visible_func(self._should_show_result)
        self.set_model(self._filtered_model)
        
        application.settings_manager.connect_event("setting_value_changed", lambda s, k, v, m: m.refilter(), self._filtered_model)
        
        self._columns = {
        }
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Title"))
        col.set_resizable(True)
        col.set_reorderable(True)
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter: cell.set_property("text", model.get_value(iter, 0).title))
        self._columns["title"] = col
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Category"))
        col.set_resizable(True)
        col.set_reorderable(True)
        self._columns["category"] = col
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Date"))
        col.set_resizable(True)
        col.set_reorderable(True)
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter: cell.set_property("text", model.get_value(iter, 0).formatted_date))
        self._columns["date"] = col
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Size"))
        col.set_resizable(True)
        col.set_reorderable(True)
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter: cell.set_property("text", model.get_value(iter, 0).formatted_size))
        self._columns["size"] = col
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Seeders"))
        col.set_resizable(True)
        col.set_reorderable(True)
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter: cell.set_property("text", model.get_value(iter, 0).formatted_seeders))
        self._columns["seeders"] = col
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Leechers"))
        col.set_resizable(True)
        col.set_reorderable(True)
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter: cell.set_property("text", model.get_value(iter, 0).formatted_leechers))
        self._columns["leechers"] = col
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Comments"))
        col.set_resizable(True)
        col.set_reorderable(True)
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter: cell.set_property("text", model.get_value(iter, 0).formatted_nb_comments))
        self._columns["comments"] = col
        
        r = gtk.CellRendererText()
        col = gtk.TreeViewColumn(_("Plugin"))
        col.set_resizable(True)
        col.set_reorderable(True)
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter: cell.set_property("text", model.get_value(iter, 0).plugin.name))
        self._columns["plugin"] = col
        
        self.set_columns("title", "category", "date", "size", "seeders", "leechers", "comments", "plugin")
        
        self.get_selection().connect("changed", self._on_selection_changed)
    
    def _on_selection_changed(self, selection):
        self._trigger_event("selection_changed", self.get_selected_results())
    
    def get_selected_results(self):
        model, paths = self.get_selection().get_selected_rows()
        selection = []
        for path in paths:
            selection.append(model.get_value(model.get_iter(path), 0))
        return selection
    
    def _remove_all_columns(self):
        for i in self.get_columns():
            self.remove_column(i)
    
    def set_columns(self, *columns_list):
        self._remove_all_columns()
        for i in columns_list:
            self.append_column(self._columns[i])
    
    def clear(self):
        self._model.clear()
    
    def add_result(self, result):
        self._model.append((result,))
    
    def _should_show_result(self, model, iter):
        return model.get_value(iter, 0) != None and model.get_value(iter, 0).should_show
