# PreferencesPluginsList.py
# -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
#
# Copyright © 2012 Gwendal Le Bihan
# 
# This file is part of Torrent Search.
# 
# Torrent Search is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Torrent Search is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Torrent Search.  If not, see <http://www.gnu.org/licenses/>.

from gi.repository import Gtk

class PreferencesPluginsList(Gtk.TreeView):
    def __init__(self, search_engine):
        Gtk.TreeView.__init__(self)
        
        self._model = Gtk.ListStore(object)
        self.set_model(self._model)
        
        r = Gtk.CellRendererToggle()
        col = Gtk.TreeViewColumn(_(""))
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter, misc: cell.set_property("active", model.get_value(iter, 0).enabled))
        self.append_column(col)
        r.connect('toggled', self._on_enabled_toggled)
        
        r = Gtk.CellRendererText()
        col = Gtk.TreeViewColumn(_("Plugin name"))
        col.pack_start(r, False)
        col.set_cell_data_func(r, lambda col, cell, model, iter, misc: cell.set_property("text", model.get_value(iter, 0).name))
        self.append_column(col)
        
        search_engine.connect_event("plugins_loaded", self._on_search_engine_plugins_loaded)
    
    def _on_search_engine_plugins_loaded(self, search_engine, plugins):
        self._model.clear()
        for i in plugins:
            self._model.append((i,))
    
    def _on_enabled_toggled(self, cell, path):
        iter = self._model.get_iter(path)
        plugin = self._model.get_value(iter, 0)
        
        plugin.enabled = not plugin.enabled
